@@ -1,3 +1,4 @@
+import tempfile
 import torch
 import requests
 import json
@@ -9,12 +10,15 @@ import aiohttp
 from aiohttp import ClientSession, ClientTimeout
 from transformers import AutoTokenizer
 from transformers import AutoModel
+import ipfs_kit_py
+import ipfs_model_manager_py
+import libp2p_kit_py
 import hashlib
 import time
 from torch import Tensor
 
 class ipfs_accelerate_py:
-    def __init__(self, resources, metadata):
+    def __init__(self, resources=None, metadata=None):
         self.resources = resources
         self.metadata = metadata
         if self.resources is None:
@@ -25,6 +29,8 @@ class ipfs_accelerate_py:
             resources = {}
         if metadata is None:
             metadata = {}
+        if "role" in list(metadata.keys()):
+            self.role = metadata["role"]
         if "queues" not in list(self.resources.keys()):
             self.resources["queues"] = {}
         if "queue" not in list(self.resources.keys()):
@@ -41,28 +47,30 @@ class ipfs_accelerate_py:
             self.resources["caches"] = {}
         if "tokenizer" not in list(self.resources.keys()):
             self.resources["tokenizer"] = {}
-        self.resources["ipfs_accelerate_py"] = self
-        if "test_ipfs_accelerate_py" not in globals() and "test_ipfs_accelerate" not in list(self.resources.keys()):
-            try:
-                from .test_ipfs_accelerate import test_ipfs_accelerate
-            except:
-                from test_ipfs_accelerate import test_ipfs_accelerate
-            self.test_ipfs_accelerate = test_ipfs_accelerate(self.resources, self.metadata)
-            resources["test_ipfs_accelerate"] = self.test_ipfs_accelerate
-        elif "test_ipfs_accelerate" in list(self.resources.keys()):
-            self.test_ipfs_accelerate = self.resources["test_ipfs_accelerate"]
-        elif "test_ipfs_accelerate" in globals():
-            self.test_ipfs_accelerate = test_ipfs_accelerate(self.resources, self.metadata) 
-            resources["test_ipfs_accelerate"] = self.test_ipfs_accelerate
-        if "install_depends_py" not in globals():
-            try:
-                from .install_depends import install_depends_py
-            except:
-                from install_depends import install_depends_py
-            self.install_depends = install_depends_py(resources, metadata)
-            resources["install_depends"] = self.install_depends 
-        else:
-            self.install_depends = install_depends_py(resources, metadata)
+        # if "test_ipfs_accelerate_py" not in globals() and "test_ipfs_accelerate" not in list(self.resources.keys()):
+        #     try:
+        #         from .test_ipfs_accelerate import test_ipfs_accelerate
+        #     except:
+        #         from test_ipfs_accelerate import test_ipfs_accelerate
+        #     self.test_ipfs_accelerate = test_ipfs_accelerate(self.resources, self.metadata)
+        #     resources["test_ipfs_accelerate"] = self.test_ipfs_accelerate
+        # elif "test_ipfs_accelerate" in list(self.resources.keys()):
+        #     self.test_ipfs_accelerate = self.resources["test_ipfs_accelerate"]
+        # elif "test_ipfs_accelerate" in globals():
+        #     self.test_ipfs_accelerate = test_ipfs_accelerate(self.resources, self.metadata) 
+        #     resources["test_ipfs_accelerate"] = self.test_ipfs_accelerate
+
+        # if "install_depends_py" not in globals():
+        #     try:
+        #         from .install_depends import install_depends_py
+        #     except:
+        #         from install_depends import install_depends_py
+        #     self.install_depends = install_depends_py(resources, metadata)
+        #     resources["install_depends"] = self.install_depends 
+        # else:
+        #     self.install_depends = install_depends_py(resources, metadata)
+        #     resources["install_depends"] = self.install_depends
+
         if "worker" not in globals():
             try:
                 from .worker import worker
@@ -70,6 +78,7 @@ class ipfs_accelerate_py:
                 from worker import worker
             self.worker = worker.worker_py(resources, metadata)
             resources["worker"] = self.worker
+
         if "ipfs_multiformats" not in globals():
             try:
                 from .ipfs_multiformats import ipfs_multiformats_py
@@ -77,6 +86,22 @@ class ipfs_accelerate_py:
                 from ipfs_multiformats import ipfs_multiformats_py
             self.ipfs_multiformats = ipfs_multiformats_py(resources, metadata)
             resources["ipfs_multiformats"] = self.ipfs_multiformats
+
+        if "ipfs_transformers" not in globals():
+            try:
+                import ipfs_transformers_py
+            except:
+                from ipfs_transformers_py import ipfs_transformers_py
+            self.ipfs_transformers_py = ipfs_transformers_py.ipfs_transformers
+            resources["ipfs_transformers_py"] = self.ipfs_transformers_py
+
+        self.metadata["role"] = self.role
+        self.ipfs_kit_py = ipfs_kit_py.ipfs_kit(resources, metadata)
+        resources["ipfs_kit"] = self.ipfs_kit_py
+        self.libp2p_kit_py = libp2p_kit_py.libp2p_kit(resources, metadata)
+        resources["libp2p_kit"] = self.libp2p_kit_py
+        self.ipfs_model_manager_py = ipfs_model_manager_py.ipfs_model_manager(resources, metadata)
+        resources["ipfs_model_manager"] = self.ipfs_model_manager_py
         self.endpoint_status = {}
         self.endpoint_handler = {}
         self.endpoints = {}
@@ -127,7 +152,7 @@ class ipfs_accelerate_py:
                 for byte_block in iter(lambda: f.read(4096),b""):
                     sha256.update(byte_block)
             install_file_hash = sha256.hexdigest()
-            test_results_file = "/tmp/" + install_file_hash + ".json"
+            test_results_file = os.path.join(tempfile.gettempdir(), install_file_hash + ".json")
             if os.path.exists(test_results_file):
                 try:
                     with open(test_results_file, "r") as f:
@@ -224,7 +249,7 @@ class ipfs_accelerate_py:
                 self.resources["tokenizer"][model] = {}
             tokenizers = list(self.resources["tokenizer"][model].keys())
             if len(tokenizers) == 0:
-                self.resources["tokenizer"][model]["cpu"] = AutoTokenizer.from_pretrained(model, device='cpu')
+                self.resources["tokenizer"][model]["cpu"] = AutoTokenizer.from_pretrained(model, device='cpu', use_fast=True, trust_remote_code=True)
                 tokens = await self.resources["tokenizer"][model]["cpu"](x, return_tensors="pt", padding=True, truncation=True)
             else:
                 for tokenizer in tokenizers:
@@ -248,7 +273,6 @@ class ipfs_accelerate_py:
         return handler
 
     async def init_endpoints(self, models=None, endpoint_list=None):
-
         endpoint_set = set(endpoint_list)
         for endpoint_type in self.endpoint_types:
             if endpoint_type in endpoint_set:
@@ -358,6 +382,7 @@ class ipfs_accelerate_py:
             self.worker_resources = await self.worker.init_worker(models, self.endpoints["local_endpoints"], None)
         except Exception as e:
             print(e)
+            print(e.__traceback__)
             self.worker_resources = e
             pass
         
@@ -789,116 +814,6 @@ class ipfs_accelerate_py:
                 print(e)
                 pass
         return None
-    
-    async def max_batch_size_bak(self, model, endpoint, endpoint_handler):
-        import psutil
-        process = psutil.Process(os.getpid())
-        embed_fail = False
-        context_length = None
-        exponent = int(0)
-        batch = []
-        token_length_size = 0
-        batch_size = 2**exponent
-        test_tokens = []
-        endpoint_types = list(self.endpoints.keys())
-
-        this_tokenizer = self.resources["tokenizer"][model][endpoint]
-        for endpoint_type in endpoint_types:
-            endpoints = self.endpoints[endpoint_type]
-            if model in list(endpoints.keys()):
-                for this_endpoint in endpoints[model]:
-                    if model == this_endpoint[0] and ( endpoint == this_endpoint[1] or this_endpoint[1] in list(self.resources["endpoint_handler"][model].keys()) ):
-                        context_length = this_endpoint[2]
-                        token_length_size = round(int(context_length) * 0.99)
-                        break
-            if token_length_size > 0:
-                break
-                        
-        token_kv = {}
-        acceptable_tokens = "abcdefghijklmnopqrstuvwxyz"
-        for i in range(0, len(acceptable_tokens)):
-            find_token_int = this_tokenizer.encode(acceptable_tokens[i])
-            if len(find_token_int) == 3:
-                find_token_int = find_token_int[1]
-            elif len(find_token_int) == 2:
-                find_token_int = find_token_int[1]
-            elif len(find_token_int) == 1:
-                find_token_int = find_token_int[0]
-            token_kv[acceptable_tokens[i]] = find_token_int
-                        
-        memory_increase = None
-        while not embed_fail:
-            test_batch = []
-            exponent += 1
-            for i in range(2**(exponent)):
-                random_offset = random.randint(0, len(acceptable_tokens)-1)
-                test_tokens = []
-                for i in range(token_length_size):
-                    test_tokens.append(token_kv[list(token_kv.keys())[(i + random_offset) % len(acceptable_tokens)]])
-                    pass
-                test_text = this_tokenizer.decode(test_tokens)
-                test_batch.append(test_text)
-            parsed_knn_embeddings = None
-            embeddings = None
-            request_knn_results = None
-            start_time = time.time()
-            start_mem = process.memory_info().rss
-            free_memory = psutil.virtual_memory().free
-            if memory_increase is not None:
-                if free_memory < (memory_increase * 2):
-                    embed_fail = True
-                    break
-                    raise(ValueError("the system does not free system memory for batch size " + str(2**(exponent-1))))
-            try:
-                if "cuda" not in endpoint and "cpu" not in endpoint and "openvino:" not in endpoint:
-                    request_knn_results = await endpoint_handler({"inputs": test_batch})
-                    end_memory = process.memory_info().rss
-
-                elif "cuda" in endpoint or "cpu" in endpoint or "openvino:" in endpoint:
-                    try:
-                        request_knn_results = await endpoint_handler(test_batch)
-                        end_memory = process.memory_info().rss
-                    except Exception as e:
-                        pass
-                    if request_knn_results == None:
-                        try:
-                            request_knn_results = endpoint_handler(test_batch)
-                            end_memory = process.memory_info().rss
-                        except Exception as e:
-                            request_knn_results = e
-                            embed_fail = True
-                            end_memory = process.memory_info().rss
-                            pass
-                        pass
-            except Exception as e:
-                request_knn_results = e
-                embed_fail = True
-                end_memory = process.memory_info().rss
-                pass
-            if request_knn_results is None or type(request_knn_results) is None or type(request_knn_results) is ValueError or type(request_knn_results) is Exception or type(request_knn_results) is str or type(request_knn_results) is int:
-                embed_fail = True
-            end_time = time.time()
-            batch_size = 2**(exponent-1)
-            elapsed_time = end_time - start_time
-            memory_increase = end_memory - start_mem
-            free_memory = psutil.virtual_memory().free
-            log = {
-            "batch size": batch_size,
-            "elapsed_time": elapsed_time,
-            "memory_increase": memory_increase,
-            "free_memory": free_memory
-            }
-            print(log)
-            self.resources["batch_sizes"][model][endpoint] = int(2**(exponent-1))
-            if batch_size >= 4096:
-                embed_fail = True
-                pass
-        if exponent == 0:
-            torch.cuda.empty_cache()
-            return 1
-        else:  
-            torch.cuda.empty_cache()
-            return 2**(exponent-1)
 
     
     async def max_batch_size(self, model, endpoint, endpoint_handler):
@@ -924,16 +839,22 @@ class ipfs_accelerate_py:
                         break
             if token_length_size > 0:
                 break
-                        
-        find_token_int = this_tokenizer.encode(find_token_str)
-        if len(find_token_int) == 3:
-            find_token_int = find_token_int[1]
-        elif len(find_token_int) == 2:
-            find_token_int = find_token_int[1]
-        elif len(find_token_int) == 1:
-            find_token_int = find_token_int[0]
-        for i in range(token_length_size):
-            test_tokens.append(find_token_int)
+        if "encode" in list(dir(this_tokenizer)):
+            find_token_int = this_tokenizer.encode(find_token_str)
+        else:
+            find_token_int = this_tokenizer(find_token_str)
+        if type(find_token_int) is dict:
+            if "input_ids" in list(find_token_int.keys()):
+                find_token_int = find_token_int["input_ids"][1]
+        elif type(find_token_int) is list:
+            if len(find_token_int) == 3:
+                find_token_int = find_token_int[1]
+            elif len(find_token_int) == 2:
+                find_token_int = find_token_int[1]
+            elif len(find_token_int) == 1:
+                find_token_int = find_token_int[0]
+            for i in range(token_length_size):
+                test_tokens.append(find_token_int)
         test_text = this_tokenizer.decode(test_tokens)
         memory_increase = None
         while not embed_fail:
@@ -1004,84 +925,6 @@ class ipfs_accelerate_py:
             with torch.no_grad():
                 torch.cuda.empty_cache()
             return 2**(exponent-1)
-
-    async def max_batch_size_bak(self, model, endpoint=None, endpoint_type=None ):
-        embed_fail = False
-        exponent = 0
-        batch = []
-        token_length_size = 0
-        batch_size = 2**exponent
-        if endpoint_type is None:
-            this_model = None
-            this_endpoint = None
-            this_context_length = None
-            if "/embed" in endpoint:
-                endpoint_type = "tei_endpoints"
-            elif "/infer" in endpoint:
-                endpoint_type = "openvino_endpoints"
-            elif "http" in endpoint:
-                endpoint_type = "tei_endpoints"
-            elif "cuda" in endpoint or "cpu" in endpoint or "local" in endpoint:
-                endpoint_type = "local_endpoints"
-            elif "libp2p" in endpoint:
-                endpoint_type = "libp2p_endpoints"
-            if endpoint_type is None:
-                print('Endpoint not found')
-                return 0
-            else:
-                pass
-                  
-            for this_endpoint in self.endpoints[endpoint_type]:
-                if "cuda" in this_endpoint[1] or "cpu" in this_endpoint[1] or "local" in this_endpoint[1]:
-                    this_endpoint_index = self.endpoints[endpoint_type].index(this_endpoint)
-                    token_length_size = round(self.endpoints["local_endpoints"][this_endpoint_index][2] * 0.99)
-                elif model is this_endpoint[0]:
-                    this_endpoint_index = self.endpoints[endpoint_type].index(this_endpoint)
-                    token_length_size = round(self.endpoints[endpoint_type][this_endpoint_index][2] * 0.99) 
-            
-            test_tokens = []
-            if model not in self.tokenizer.keys():
-                self.tokenizer[model] = {}
-            if "cpu" not in self.tokenizer[model].keys():
-                self.tokenizer[model]["cpu"] = AutoTokenizer.from_pretrained(model, device='cpu')
-            find_token_str = str("z")
-            find_token_int = self.tokenizer[model]["cpu"].encode(find_token_str)
-            if len(find_token_int) == 3:
-                find_token_int = find_token_int[1]
-            elif len(find_token_int) == 2:
-                find_token_int = find_token_int[1]
-            elif len(find_token_int) == 1:
-                find_token_int = find_token_int[0]
-            for i in range(token_length_size):
-                test_tokens.append(find_token_int)
-            test_text = self.tokenizer[model]["cpu"].decode(test_tokens)
-            if endpoint is None:
-                endpoint = self.choose_endpoint(model)
-            while not embed_fail:
-                test_batch = []
-                for i in range(batch_size):
-                    test_batch.append(test_text)
-                parsed_knn_embeddings = None
-                embeddings = None
-                request_knn_results = None
-                try:
-                    request_knn_results = await self.request_knn(test_batch, model, endpoint, endpoint_type)
-                except Exception as e:
-                    try:
-                        embeddings = await self.index_knn(test_batch, model, endpoint)
-                    except Exception as e:
-                            pass
-                if request_knn_results != None and parsed_knn_embeddings == None:
-                    parsed_knn_embeddings = await self.parse_knn(request_knn_results, model, endpoint, endpoint_type)
-                if parsed_knn_embeddings is not None:
-                    embeddings = parsed_knn_embeddings
-                embed_fail = True
-                
-        self.endpoint_status[endpoint] = 2**(exponent-1)
-        if exponent == 0:
-            return 1
-        else:
-            return 2**(exponent-1)
     
     async def request_openvino_endpoint(self, model, batch_size):
         if model in self.openvino_endpoints:
@@ -1670,103 +1513,88 @@ class ipfs_accelerate_py:
         The quick brown fox jumps over the lazy dog. \n
         '''
         sentence_2 = "Now is the time for all good Men to come to the aid of their country."
-        batch = [sentence_1, sentence_2]
-        max_batch_size1 = await self.max_batch_size(metadata['models'][0], "cuda:1", self.resources["endpoint_handler"][metadata['models'][0]]["cuda:1"])
-        max_batch_size2 = await self.max_batch_size(metadata['models'][0], "cuda:1", self.resources["endpoint_handler"][metadata['models'][0]]["cuda:1"])
-        max_batch_size3 = await self.max_batch_size(metadata['models'][0], "cuda:1", self.resources["endpoint_handler"][metadata['models'][0]]["cuda:1"])
-        del self.max_batch_size 
-        test_batch = self.resources["endpoint_handler"][metadata['models'][0]]["cuda:1"](batch)
+        # batch = [sentence_1, sentence_2]
+        # max_batch_size1 = await self.max_batch_size(metadata['models'][0], "openvino:0", self.resources["endpoint_handler"][metadata['models'][0]]["openvino:0"])
+        # max_batch_size2 = await self.max_batch_size(metadata['models'][0], "openvino:0", self.resources["endpoint_handler"][metadata['models'][0]]["openvino:0"])
+        test_batch = self.resources["endpoint_handler"][metadata['models'][0]]["openvino:0"](sentence_2)
 
         # test_batch_sizes = await self.test_batch_sizes(metadata['models'], ipfs_accelerate_init)
         with torch.no_grad():
-            torch.cuda.empty_cache()
+            if "cuda" in dir(torch):
+                torch.cuda.empty_cache()
         results = {
             "ipfs_accelerate_init": ipfs_accelerate_init,
             "test_endpoints": test_endpoints,
             "test_batch": test_batch,
-            "max_batch_size": max_batch_size1,
-            "max_batch_size": max_batch_size2,
-            "max_batch_size": max_batch_size3,
+            # "max_batch_size": max_batch_size1,
+            # "max_batch_size": max_batch_size2,
             # "test_batch_sizes": test_batch_sizes
         }
         return results
 
 ipfs_accelerate_py = ipfs_accelerate_py
-
+    
 if __name__ == "__main__":
     metadata = {
-        "dataset": "TeraflopAI/Caselaw_Access_Project",
-        "namespace": "TeraflopAI/Caselaw_Access_Project",
-        "column": "text",
+        "dataset": "laion/gpt4v-dataset",
+        "namespace": "laion/gpt4v-dataset",
+        "column": "link",
+        "role": "master",
         "split": "train",
         "models": [
-            "thenlper/gte-small",
-            # "Alibaba-NLP/gte-large-en-v1.5",
-            # "Alibaba-NLP/gte-Qwen2-1.5B-instruct",
+            # "TIGER-Lab/Mantis-8B-siglip-llama3",
+            # "lmms-lab/llava-onevision-qwen2-7b-si",  
+            # "lmms-lab/llava-onevision-qwen2-7b-ov", 
+            # "lmms-lab/LLaVA-Video-7B-Qwen2",
+            # "llava-hf/llava-v1.6-mistral-7b-hf",
+            # "meta-llama/Meta-Llama-3-8B-Instruct",
+            "TinyLlama/TinyLlama-1.1B-Chat-v1.0", 
+            # "Qwen/Qwen2-7B",
+            # "llava-hf/llava-interleave-qwen-0.5b-hf",
+            # "lmms-lab/llava-onevision-qwen2-0.5b-si", 
+            # "lmms-lab/llava-onevision-qwen2-0.5b-ov", 
+            # "Qwen/Qwen2-VL-7B-Instruct", ## convert_model() ->   ('Couldn\'t get TorchScript module by scripting. With exception:\nComprehension ifs are not supported yet:\n  File "/home/devel/.local/lib/python3.12/site-packages/transformers/models/qwen2_vl/modeling_qwen2_vl.py", line 1187\n    \n        if not return_dict:\n            return tuple(v for v in [hidden_states, next_cache, all_hidden_states, all_self_attns] if v is not None)\n        return BaseModelOutputWithPast(\n            last_hidden_state=hidden_states,\n\n\nTracing sometimes provide better results, please provide valid \'example_input\' argument. You can also provide TorchScript module that you obtained yourself, please refer to PyTorch documentation: https://pytorch.org/tutorials/beginner/Intro_to_TorchScript_tutorial.html.',)
+            # "OpenGVLab/InternVL2_5-1B", ## convert_model() -> torchscript error Couldn't get TorchScript module by scripting. With exception: try blocks aren't supported:
+            # "OpenGVLab/InternVL2_5-8B", ## convert_model() -> torchscript error Couldn't get TorchScript module by scripting. With exception: try blocks aren't supported:
+            # "OpenGVLab/PVC-InternVL2-8B", ## convert_model() -> torchscript error Couldn't get TorchScript module by scripting. With exception: try blocks aren't supported:
+            # "AIDC-AI/Ovis1.6-Llama3.2-3B", # ValueError: Trying to export a ovis model, that is a custom or unsupported architecture,
+            # "BAAI/Aquila-VL-2B-llava-qwen", # Asked to export a qwen2 model for the task visual-question-answering (auto-detected), but the Optimum OpenVINO exporter only supports the tasks feature-extraction, feature-extraction-with-past, text-generation, text-generation-with-past, text-classification for qwen2. Please use a supported task. Please open an issue at https://github.com/huggingface/optimum/issues if you would like the task visual-question-answering to be supported in the ONNX export for qwen2.
+            # "laion/larger_clap_general",
+            # "google/vit-base-patch16-224"
         ],
         "chunk_settings": {
-            "chunk_size": 512,
-            "n_sentences": 8,
-            "step_size": 256,
-            "method": "fixed",
-            "embed_model": "thenlper/gte-small",
-            "tokenizer": None
+
         },
-        "dst_path": "/storage/teraflopai/tmp",
+        "path": "/storage/gpt4v-dataset/data",
+        "dst_path": "/storage/gpt4v-dataset/data",
     }
     resources = {
         "local_endpoints": [
-            ["thenlper/gte-small", "cpu", 512],
-            ["Alibaba-NLP/gte-large-en-v1.5", "cpu", 8192],
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "cpu", 32768],
-            ["thenlper/gte-small", "cuda:0", 512],
-            ["Alibaba-NLP/gte-large-en-v1.5", "cuda:0", 8192],
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "cuda:0", 32768],
-            ["thenlper/gte-small", "cuda:1", 512],
-            ["Alibaba-NLP/gte-large-en-v1.5", "cuda:1", 8192],
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "cuda:1", 32768],
-            ["thenlper/gte-small", "openvino:0", 512],
-            ["Alibaba-NLP/gte-large-en-v1.5", "openvino:0", 8192],
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "openvino:0", 32768],
-            ["thenlper/gte-small", "llama_cpp", 512],
-            ["Alibaba-NLP/gte-large-en-v1.5", "llama_cpp", 8192],
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "llama_cpp", 32768],
-            ["thenlper/gte-small", "ipex", 512],
-            ["Alibaba-NLP/gte-large-en-v1.5", "ipex", 8192],
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "ipex", 32768],
+            ["meta-llama/Meta-Llama-3-8B-Instruct",  "cpu", 32768],
+            ["Qwen/Qwen2-7B", "cpu", 32768],
+            ["TinyLlama/TinyLlama-1.1B-Chat-v1.0",    "cpu", 32768],
+            ["meta-llama/Meta-Llama-3-8B-Instruct",  "cuda:0", 32768],
+            ["Qwen/Qwen2-7B", "cuda:0", 32768],
+            ["TinyLlama/TinyLlama-1.1B-Chat-v1.0",    "cuda:0", 32768],
+            ["meta-llama/Meta-Llama-3-8B-Instruct",  "cuda:1", 32768],
+            ["Qwen/Qwen2-7B", "cuda:1", 8192],
+            ["TinyLlama/TinyLlama-1.1B-Chat-v1.0",    "cuda:1", 32768],
+            ["meta-llama/Meta-Llama-3-8B-Instruct",  "openvino:2", 32768],
+            ["Qwen/Qwen2-7B", "openvino:2", 32768],
+            ["TinyLlama/TinyLlama-1.1B-Chat-v1.0",    "openvino:2", 32768],
+            ["meta-llama/Meta-Llama-3-8B-Instruct",  "llama_cpp", 512],
+            ["Qwen/Qwen2-7B", "llama_cpp", 8192],
+            ["TinyLlama/TinyLlama-1.1B-Chat-v1.0",    "llama_cpp", 32768],
+            ["meta-llama/Meta-Llama-3-8B-Instruct",  "ipex", 512],
+            ["Qwen/Qwen2-7B", "ipex", 8192],
+            ["TinyLlama/TinyLlama-1.1B-Chat-v1.0",    "ipex", 32768],
         ],
         "openvino_endpoints": [
-            # ["neoALI/bge-m3-rag-ov", "https://bge-m3-rag-ov-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-rag-ov/infer", 4095],
-            # ["neoALI/bge-m3-rag-ov", "https://bge-m3-rag-ov-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-rag-ov/infer", 4095],
-            # ["neoALI/bge-m3-rag-ov", "https://bge-m3-rag-ov-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-rag-ov/infer", 4095],
-            # ["neoALI/bge-m3-rag-ov", "https://bge-m3-rag-ov-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-rag-ov/infer", 4095],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx0-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx0/infer", 1024],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx1-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx1/infer", 1024],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx2-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx2/infer", 1024],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx3-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx3/infer", 1024],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx4-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx4/infer", 1024],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx5-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx5/infer", 1024],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx6-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx6/infer", 1024],
-            # ["aapot/bge-m3-onnx", "https://bge-m3-onnx7-endomorphosis-dev.apps.cluster.intel.sandbox1234.opentlc.com/v2/models/bge-m3-onnx7/infer", 1024]
         ],
         "tei_endpoints": [
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "http://62.146.169.111:8080/embed-medium", 32768],
-            ["thenlper/gte-small", "http://62.146.169.111:8080/embed-tiny", 512],
-            ["Alibaba-NLP/gte-large-en-v1.5", "http://62.146.169.111:8081/embed-small", 8192],
-            ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "http://62.146.169.111:8081/embed-medium", 32768],
-            ["thenlper/gte-small", "http://62.146.169.111:8081/embed-tiny", 512],
-            # ["Alibaba-NLP/gte-large-en-v1.5", "http://62.146.169.111:8082/embed-small", 8192],
-            # ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "http://62.146.169.111:8082/embed-medium", 32768],
-            # ["thenlper/gte-small", "http://62.146.169.111:8082/embed-tiny", 512],
-            # ["Alibaba-NLP/gte-large-en-v1.5", "http://62.146.169.111:8083/embed-small", 8192],
-            # ["Alibaba-NLP/gte-Qwen2-1.5B-instruct", "http://62.146.169.111:8083/embed-medium", 32768],
-            # ["thenlper/gte-small", "http://62.146.169.111:8083/embed-tiny", 512]
-        ],
-        "vllm_endpoints": [
-        ],
-        "openai_endpoints": [
         ],
     }
+
     ipfs_accelerate_py = ipfs_accelerate_py(resources, metadata)
     asyncio.run(ipfs_accelerate_py.__test__(resources, metadata))
     print("test complete")
